@@ -10,16 +10,16 @@ use dbus::strings::Path;
 use dbus_tree::{Access, Factory};
 use log::{debug, warn};
 
-use crate::album::Album;
-use crate::episode::Episode;
 use crate::events::EventManager;
 use crate::library::Library;
-use crate::playable::Playable;
-use crate::playlist::Playlist;
+use crate::model::album::Album;
+use crate::model::episode::Episode;
+use crate::model::playable::Playable;
+use crate::model::playlist::Playlist;
+use crate::model::show::Show;
+use crate::model::track::Track;
 use crate::queue::{Queue, RepeatSetting};
-use crate::show::Show;
 use crate::spotify::{PlayerEvent, Spotify, UriType, VOLUME_PERCENT};
-use crate::track::Track;
 use crate::traits::ListItem;
 use regex::Regex;
 
@@ -584,7 +584,7 @@ fn run_dbus_server(
                         if let Some(t) = &Album::from(&a).tracks {
                             queue.clear();
                             let index = queue.append_next(
-                                t.iter()
+                                &t.iter()
                                     .map(|track| Playable::Track(track.clone()))
                                     .collect(),
                             );
@@ -606,11 +606,7 @@ fn run_dbus_server(
                         playlist.load_tracks(spotify);
                         if let Some(t) = &playlist.tracks {
                             queue.clear();
-                            let index = queue.append_next(
-                                t.iter()
-                                    .map(|track| Playable::Track(track.clone()))
-                                    .collect(),
-                            );
+                            let index = queue.append_next(&t.iter().cloned().collect());
                             queue.play(index, false, false)
                         }
                     }
@@ -625,7 +621,7 @@ fn run_dbus_server(
                             let mut ep = e.clone();
                             ep.reverse();
                             let index = queue.append_next(
-                                ep.iter()
+                                &ep.iter()
                                     .map(|episode| Playable::Episode(episode.clone()))
                                     .collect(),
                             );
@@ -643,7 +639,7 @@ fn run_dbus_server(
                 Some(UriType::Artist) => {
                     if let Some(a) = spotify.api.artist_top_tracks(id) {
                         queue.clear();
-                        queue.append_next(a.iter().map(|track| Playable::Track(track.clone())).collect());
+                        queue.append_next(&a.iter().map(|track| Playable::Track(track.clone())).collect());
                         queue.play(0, false, false)
                     }
                 }
